==> racer-0.1.2.tgz: package/lib/Model.server.js <==
var BrowserModel, Promise, ServerModel, transaction;
transaction = require('./transaction');
BrowserModel = require('./Model');
Promise = require('./Promise');
module.exports = ServerModel = function() {
  var self;
  self = this;
  BrowserModel.apply(self, arguments);
  self.clientIdPromise = (new Promise).on(function(clientId) {
    return self._clientId = clientId;
  });
};
ServerModel.prototype = Object.create(BrowserModel.prototype);
ServerModel.prototype._baseOnTxn = ServerModel.prototype._onTxn;
ServerModel.prototype._onTxn = function(txn) {
  var self;
  self = this;
  return this.clientIdPromise.on(function(clientId) {
    return self.store._nextTxnNum(clientId, function(num) {
      self._txnNum = num;
      return self._baseOnTxn(txn, num);
    });
  });
};
ServerModel.prototype._commit = function(txn) {
  var self;
  self = this;
  return this.store._commit(txn, function(err, txn) {
    if (err) {
      return self._removeTxn(transaction.id(txn));
    }
    return self._onTxn(txn);
  });
};
ServerModel.prototype.bundle = function(callback) {
  var self;
  self = this;
  if (this._txnQueue.length) {
    return setTimeout((function() {
      return self.bundle(callback);
    }), 10);
  }
  return Promise.parallel(this.clientIdPromise, this.startIdPromise).on(function() {
    return self._bundle(callback);
  });
};
ServerModel.prototype._bundle = function(callback) {
  var clientId, field, otFields, path, _ref;
  clientId = this._clientId;
  this.store._pubSub.unsubscribe(clientId);
  delete this.store._localModels[clientId];
  otFields = {};
  _ref = this.otFields;
  for (path in _ref) {
    field = _ref[path];
    if (field.toJSON) {
      otFields[path] = field.toJSON();
    }
  }
  return callback(JSON.stringify({
    data: this.get(),
    otFields: otFields,
    base: this._adapter.version(),
    clientId: clientId,
    storeSubs: this._storeSubs,
    startId: this._startId,
    txnCount: this._txnCount,
    txnNum: this._txnNum,
    ioUri: this._ioUri
  }));
};
ServerModel.prototype._addSub = function(paths, callback) {
  var self, store;
  store = this.store;
  self = this;
  return this.clientIdPromise.on(function(clientId) {
    store._pubSub.subscribe(clientId, paths);
    store._localModels[clientId] = self;
    return store._fetchSubData(paths, function(err, data, otData) {
      self._initSubData(data);
      self._initSubOtData(otData);
      return callback();
    });
  });
};

==> racer-0.1.3.tgz: package/lib/Model.server.js <==
var BrowserModel, Promise, ServerModel, transaction;

transaction = require('./transaction');

BrowserModel = require('./Model');

Promise = require('./Promise');

module.exports = ServerModel = function() {
  var self;
  self = this;
  BrowserModel.apply(self, arguments);
  self.clientIdPromise = (new Promise).on(function(clientId) {
    return self._clientId = clientId;
  });
};

ServerModel.prototype = Object.create(BrowserModel.prototype);

ServerModel.prototype._baseOnTxn = ServerModel.prototype._onTxn;

ServerModel.prototype._onTxn = function(txn) {
  var self;
  self = this;
  return this.clientIdPromise.on(function(clientId) {
    return self.store._nextTxnNum(clientId, function(num) {
      self._txnNum = num;
      return self._baseOnTxn(txn, num);
    });
  });
};

ServerModel.prototype._commit = function(txn) {
  var self;
  if (txn.isPrivate) return;
  self = this;
  return this.store._commit(txn, function(err, txn) {
    if (err) return self._removeTxn(transaction.id(txn));
    return self._onTxn(txn);
  });
};

ServerModel.prototype.bundle = function(callback) {
  var self;
  self = this;
  if (this._txnQueue.length) {
    return setTimeout((function() {
      return self.bundle(callback);
    }), 10);
  }
  return Promise.parallel(this.clientIdPromise, this.startIdPromise).on(function() {
    return self._bundle(callback);
  });
};

ServerModel.prototype._bundle = function(callback) {
  var clientId, field, otFields, path, _ref;
  clientId = this._clientId;
  this.store._pubSub.unsubscribe(clientId);
  delete this.store._localModels[clientId];
  otFields = {};
  _ref = this.otFields;
  for (path in _ref) {
    field = _ref[path];
    if (field.toJSON) otFields[path] = field.toJSON();
  }
  return callback(JSON.stringify({
    data: this.get(),
    otFields: otFields,
    base: this._adapter.version(),
    clientId: clientId,
    storeSubs: this._storeSubs,
    startId: this._startId,
    txnCount: this._txnCount,
    txnNum: this._txnNum,
    ioUri: this._ioUri
  }));
};

ServerModel.prototype._addSub = function(paths, callback) {
  var self, store;
  store = this.store;
  self = this;
  return this.clientIdPromise.on(function(clientId) {
    store._pubSub.subscribe(clientId, paths);
    store._localModels[clientId] = self;
    return store._fetchSubData(paths, function(err, data, otData) {
      self._initSubData(data);
      self._initSubOtData(otData);
      return callback();
    });
  });
};
